@@ -279,16 +279,19 @@ def insert_class_closure(
     if current_closure is None:
         current_closure = ()
     new_globals = globals()
-    if function.__module__ and function.__module__ != "__main__":
+    if function.__module__:
         module = import_module(function.__module__)
         new_globals = module.__dict__
 
     # Resynthesize the errant __class__ cell with the correct one in the CORRECT position
     # This will allow for overridden functions to be called with super()
     co_freevars_values = (*current_closure[:index], class_cell, *current_closure[index + 1 :])
-    return types.FunctionType(
+    new_function = types.FunctionType(
         code, new_globals, function.__name__, function.__defaults__, co_freevars_values
     )
+    new_function.__kwdefaults__ = function.__kwdefaults__
+    new_function.__annotations__ = function.__annotations__
+    return new_function
 
 
 def explode(*args, **kwargs):
